
// ULTRASONIC\0 ec:38:6b:10:eo:e4


#include <stdint.h>
#include <string.h>
#include <stdbool.h>
#include <stdio.h>
#include "esp_spi_flash.h"
#include "esp_system.h"
#include "nvs.h"
#include "nvs_flash.h"

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"

#include "ultrasonic.h"
#include "gps.h"
#include "nmea.h"


static void on_wind_data(int windSpeed, int windDir, int battery,
        int temp, int roll, int pitch, int compass)
{
    float wind = (float)windSpeed / (float)100.0 * (float)1.94384;
    char buf[100], msg[110];
    sprintf(buf, "$WIMWV,%d.0,R,%.1f,N,A", windDir, wind);
    nmea_make_message(msg, buf);
    printf("%s", msg);
//    printf("wind speed: %f dir: %d, battery: %d%% temperature: %dC roll: %d pitch: %d dir: %d raw speed %d:\n", 
//            wind, windDir, battery, temp, roll, pitch, compass, windSpeed);
}


static void on_ultrasonic_status_changed(int state)
{
    switch (state) {
        case ULTRASONIC_STATE_SUBSCRIBED:
            ultrasonic_set_rate(1);
            ultrasonic_enable_sensors(1);
            break;
    }
}


/*static void say_hello()
{
    printf("Smart Boat Controller v1.0\n");
    // Print chip information
    esp_chip_info_t chip_info;
    esp_chip_info(&chip_info);
    printf("This is ESP32 chip with %d CPU cores, WiFi%s%s, ",
            chip_info.cores,
            (chip_info.features & CHIP_FEATURE_BT) ? "/BT" : "",
            (chip_info.features & CHIP_FEATURE_BLE) ? "/BLE" : "");
    printf("silicon revision %d, ", chip_info.revision);
    printf("%dMB %s flash\n", spi_flash_get_chip_size() / (1024 * 1024),
            (chip_info.features & CHIP_FEATURE_EMB_FLASH) ? "embedded" : "external");
}*/


void app_main()
{
    // Initialize NVS.
    esp_err_t ret = nvs_flash_init();
    if (ret == ESP_ERR_NVS_NO_FREE_PAGES) {
        ESP_ERROR_CHECK(nvs_flash_erase());
        ret = nvs_flash_init();
    }
    ESP_ERROR_CHECK(ret);

//    say_hello();

    xTaskCreate(&gps_task, "gps_task", 4096, NULL, 5, NULL);

    ultrasonic_init(NULL, on_wind_data, on_ultrasonic_status_changed);
}

