#include "ubx.h"
#include <string.h>
#include <stdio.h>


static void setUint32(uint8_t *buf, int value)
{
    buf[0] = value & 0xFF;
    buf[1] = (value >> 8) & 0xFF;
}

int ubx_make_message(uint8_t *res, char msgClass, char msgId, uint8_t *data, int dataLen)
{
    res[0] = 0xB5;
    res[1] = 0x62;
    res[2] = msgClass;
    res[3] = msgId;
    res[4] = dataLen & 0xFF;
    res[5] = (dataLen >> 8) & 0xFF;
    memcpy(res + 6, data, dataLen);
    
    uint8_t CK_A = 0, CK_B = 0;
    for (int i = 2; i < dataLen + 6; i++) {
        CK_A = CK_A + (unsigned char)res[i];
        CK_B = CK_B + CK_A;
    }
    res[6 + dataLen] = CK_A;
    res[6 + dataLen + 1] = CK_B;

    return dataLen + 8;
}

int ubx_is_message_reeived(uint8_t *data, int len, int *start, int *length)
{
    if (len < 8)
        return 0;
    for (int i = 0; i < len - 8; i++) {
        if ((0xB5 == data[i]) && (0x62 == data[i + 1])) {
            int msgLen = data[i + 4] | (data[i + 5] << 8);
            if (i + msgLen + 8 > len)
                return 0;
            if (start)
                *start = i;
            if (length)
                *length = msgLen;
            return 1;
        }
    }
    return 0;
}

int ubx_make_rate_message(uint8_t *res, int rate)
{
    uint8_t payload[4];
    payload[0] = rate;
    payload[1] = payload[2] = payload[3] = 0;
    return ubx_make_message(res, 0x06, 0x5C, payload, sizeof(payload));
}

int ubx_make_rates_message(uint8_t *res, int rate)
{
    uint8_t payload[6];
    setUint32(payload, 1000 / rate);
    setUint32(payload + 2, 1);
    setUint32(payload + 4, 1);
    return ubx_make_message(res, 0x06, 0x08, payload, sizeof(payload));
}

int ubx_make_platform_model_message(uint8_t *res, int model)
{
    uint8_t payload[36];
    memset(payload, 0, sizeof(payload));
    payload[0] = 1;
    payload[2] = model;
    return ubx_make_message(res, 0x06, 0x24, payload, sizeof(payload));
}
