#ifndef __ULTRASONIC_H__
#define __ULTRASONIC_H__

#include <stdint.h>

// callback for wind status updates
// windSpeed - speed of wind in m/s multiplied by 100
// windDir - wind direction in degrees
// battery - battery level in percents
// temp - temperature in degrees of celsius
// roll - roll in degrees
// pitch - pitch in degrees
// compass - value of compass in degrees
typedef void (*ultrasonic_data_cb)(int windSpeed, int windDir, int battery,
        int temp, int roll, int pitch, int compass);

#define ULTRASONIC_STATE_NOT_STARTED 0
#define ULTRASONIC_STATE_DISCOVERING 1
#define ULTRASONIC_STATE_CONNECTING 2
#define ULTRASONIC_STATE_CONNECTED 3
#define ULTRASONIC_STATE_SUBSCRIBED 4

// called when connection status changed
typedef void (*ultrasonic_status_cb)(int state);

// initialize ultrasonic connection
// activates bluetooth and starts device discovering
// returns non-zero on errors
int ultrasonic_init(uint8_t *id, ultrasonic_data_cb on_data_received,
        ultrasonic_status_cb on_status_changed);

// returns current ultrasonic connection status
int ultrasonic_get_connection_state();

#define ULTRASONIC_POWER_SLEEP 0
#define ULTRASONIC_POWER_LOW 1
#define ULTRASONIC_POWER_NORMAL 2

// returns current power mode
// 0 -> Sleep Mode, Only Advertising
// 1 -> Low Power Mode, 1hz and Sensors disabled
// 2 -> Normal Mode, All data rate and sensors availables
int ultrasonic_get_power_mode();

// returns current update rate in Hz
int ultrasonic_get_rate();

// set update rate.  only accepted values are 1, 4 and 8
void ultrasonic_set_rate(int rate);

// returns 1 if clinometer and eCompass are active
int ultrasonic_are_sensors_enabled();

// enable or disable clinometer and eCompass
void ultrasonic_enable_sensors(int enable);

// returns wind direction offset (compensates mounting direction)
int ultrasonic_get_angle_offset();

// set angle offset for mounting direction compensation
void ultrasonic_set_angle_offset(int offset);

// returns 1 if ultrasonic is in compass calibration mode
int ultrasonic_get_compass_calibration_mode();

// enable compass calibration mode
void ultrasonic_enable_compass_calibration_mode(int enable);


#endif

